#
# spec file for package torsocks
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define _name  libtorsocks
Name:           torsocks
Version:        2.1.0
Release:        6.1
Summary:        Use SOCKS-friendly applications with Tor
License:        GPL-2.0
Group:          Productivity/Networking/Security
Url:            https://github.com/dgoulet/torsocks
Source0:        https://github.com/dgoulet/%{name}/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        %{name}-rpmlintrc
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
Requires:       tor
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Torsocks allows you to use most applications in a safe way with Tor.
It ensures that DNS requests are handled safely and explicitly rejects
any traffic other than TCP from the application you're using.

Torsocks is an ELF shared library that is loaded before all others.
The library overrides every needed Internet communication libc function
calls such as connect(2) or gethostbyname(3).

This process is transparent to the user and if torsocks detects any
communication that can't go through the Tor network such as UDP traffic,
for instance, the connection is denied. If, for any reason, there is no way
for torsocks to provide the Tor anonymity guarantee to your application,
torsocks will force the application to quit and stop everything.

Adjust when needed /etc/tor/torsocks.conf and use Torsocks with

    torsocks application

So, for example you can use ssh to a some.ssh.com by doing

    torsocks ssh -p SSH-Port -i ~/.ssh/ssh-key.rsa username@some.ssh.com

You can use in /etc/bash.bashrc.local or /etc/zsh.zshrc.local alias

    alias slogin-='torsocks slogin'

And can ajust ~/.ssh/config with your data for server or PC and then use simple

    slogin- server

or add too an alias

    alias slogin-server='slogin- server'

and use simple

    slogin-server

%prep
%setup -q

%build
autoreconf -fi

%configure --docdir=%{_defaultdocdir}/%{name}
make %{?_smp_mflags}

%install
%make_install

# Remove not needed static libraries
rm %{buildroot}/%{_libdir}/%{name}/lib%{name}.{a,la}

%post   -n %{name} -p /sbin/ldconfig

%postun -n %{name} -p /sbin/ldconfig

%files
%defattr(-,root,root,-)
%doc ChangeLog README.md gpl-2.0.txt TODO doc/socks/SOCKS5 doc/socks/socks-extensions.txt doc/notes/DEBUG extras/torsocks-bash_completion extras/torsocks-zsh_completion
%{_bindir}/%{name}
%{_mandir}/man1/%{name}.1%{ext_man}
%{_mandir}/man5/%{name}.conf.5%{ext_man}
%{_mandir}/man8/%{name}.8%{ext_man}
%dir %{_libdir}/%{name}
%{_libdir}/%{name}/%{_name}.so*
%config(noreplace) %{_sysconfdir}/tor/%{name}.conf
%dir %attr(0755,root,tor) %{_sysconfdir}/tor

%changelog
* Tue Jun  9 2015 nemysis@gmx.ch
- Use %%attr(0755,root,tor) %%{_sysconfdir}/tor instead of %%{_sysconfdir}/tor
* Fri May 29 2015 nemysis@gmx.ch
- Update to 2.1.0, announce message:
  2015-05-27 torsocks 2.1.0
  * Fix: socks5 resolve wasn't sending data correctly
  * Fix: wrong label when auth_socks5 fail
  * Move SOCKS5 auth in a seperate function
  * Send the SOCKS5 authentication for RESOLVE/RESOLVE_PTR requests.
  * Change IsolatePID password from 42 to 0
  * Add automatic per process isolation (IsolatePID)
  * Ensure that torsocks initializes itself in the presence of C++.
  * Merge remote-tracking branch 'yawning/getaddrinfo' into getaddrinfo
  * Fix: indentation in getpeername test
  * Merge remote-tracking branch 'yawning/getpeername'
  * Add support for the various inotify routines when invoked via syscall().
  * Support the eventfd2(2) syscall.
  * Support the various epoll routines when invoked via syscall().
  * Handle accept4(2) when invoked via syscall().
  * Fix getaddrinfo() to respect AI_NUMERICHOST.
  * Fix the broken getpeername() implementation.
  * Support certain Linux specific syscalls.
  * Allow TCP Fast Open clients go through tor
  * Test: support out of tree make check
  * configure.ac: avoid tests which have both -pie and -static
  * Fix error messages about setuid/setgid executables
  * Fix: switch back to a syscall whitelist scheme
  * Add AllowOutboundLocalhost.
  * Fix: syscall mmap for NetBSD
  * Fix: use getsockname instead of getsockopt to get socket family
  * Stop denying syscall() and add dangerous ones
  * Fix: typo in the listen macro declaration
  * Fix: improve getpeername to actually works
  * Fix: improve Unix socket passing detection
  * Test: add missing connection destroy
  * Test: possible double free in onion test
  * Test: fix memory leak in DNS test
  * Add accept as an accepted value through syscall()
  * Add cscope files to gitignore
  2014-08-11 torsocks 2.0.0
  * Fix: compilation issue on Debian kfreebsd-i386
  * Fix: add LICENSE file to repository
  * Fix: add compilation requirements to README.md
  2014-04-04 torsocks 2.0.0-rc7
  * Fix: fix NULL dereference on error
  * Fix: memory leak in connect error path
  * Delete old source directory
  * Fix: nullify constant that might be undefined
  * Refactor the connect() code flow for clarity
  * Tests: add connect() test
  * Tests: add socket() test
  * Fix: socketpair() denied for INET[6] socket
  * Fix: socket() type check SOCK_STREAM
  * Fix: add autogen.sh to installation procedures
  * Fix: change TSOCKS_LOOPBACK bitness
  * Fix: support kfreebsd for mmap()
  2014-03-17 torsocks 2.0.0-rc6
  * Fix: set addr len for getsockname in accept
  * Fix: use socket fd and NOT sockaddr in accept
  2014-03-17 torsocks 2.0.0-rc5
  * Fix: strict aliasing in library
  * Add fclose() support
  * Fix: add torsocks.conf option type
  * Add option to allow inbound connections
  * Fix: handle NULL node in getaddrinfo
  2014-03-03 torsocks 2.0.0-rc4
  * Extras: add bash and zsh completion file                                                                                                                [588/6387]
  * Fix: move functions in file and set hidden attribute
  * Update torsocks.1 man page with new options and some fixes
  * Add -u/-p/-d to torsocks script
  * Fix: check SOCKS5 user/pass before setting them in config
  * Test: add socks5 tests
  * Fix: assert conn->fd typo
  * Add SOCKS5 username/password authentication
  * Fix: handle conn. type domain name for socks5 connect
  * Fix: check strdup return value in config-file.c
  * Fix: make tsock_tor_resolve support IPv6
  * Fix: overload listen and not bind
  * Fix: remove the use of IPv4 sockaddr in connect
  * Tests: add one for utils_tokenize_ignore_comments
  * Fix: use unsigned char for socks5 ABI
  * Fix: use connection_get_ref on creation
  * Fix: use strtok_r reentrant instead of strtok
  * Fix: check is_suid flag before each getenv()
  * Deny libc function bind()
  * Deny libc function accept()/accept4()
  * Fix: handle hints being NULL in getaddrinfo
  * Fix: handle socket creation with multiple types
  * Fix: better document connection registry mutex
  * Fix: check strdup return value
  * Fix: deny connection to ANY address
  * Fix: remove all variables with double underscore
  * Fix: change socks5_send_ptr_request to use address type
  * Fix: IPv6 typo in socks5_send_resolve_ptr_request
  * Fix: assert conn->fd typo
  * Fix: build status markdown
  * Fix: return right value with localhost resolve
  * Fix: fd leak on tor resolve error
  * Fix: use libc close() when resolving through Tor
  * Fix: socks5 connect use connection domain and correct len
  * Fix: bad reference in getaddrinfo() using inet_pton
  * Test: add unit test for sockaddr_is_localhost
  * Fix: remove gethostent() usage
  * Add localhost resolve utils function
  * Fix: README typos
  * Fix: bad libc detection on system with libcap.so
  * Add portable is localhost function
  * Tests: add travis build status image to README
  * Fix: quote torsocks script shell arguments
  * Add --version to torsocks.in
  * Add hardening compile and linker flags
  * Fix: cleanup configure.ac and add missing headers/functions
  * Fix: typo in exit.c comment
  * Fix: add a library cleanup flag
  * Fix: overload _exit and _Exit to cleanup library
  * Fix: lookup libc name and pass it to dlopen()
  * Fix: bad include and duplicate syscall values
  * Fix: change non TCP socket warning to debug
  * Fix: check if address is local after onion lookup
  * Fix: put utils_is_ipv4_local static inline
  * Fix: set loopback check in host byte order
  * Fix: reject IPv6 socket creation
  * Fix: fix localhost resolution address
  * Fix: add missing errno to handle non-blocking connect()
  * Revert "Fix: explicitly remove src.old from tarball"
  * Add __syscall support for *BSD systems
  * Add NetBSD support
  * Fix: install documentation in doc directory
  * Fix: explicitly remove src.old from tarball
  * Fix: typo in README
  2013-11-03 torsocks 2.0.0-rc3
  * Fix: add fixtures directory to EXTRA_DIST
  * Fix: add fixtures.h to makefile.am as EXTRA_DIST
  * Fix: remove DBG call in syscall()
  * Fix: don't lookup symbol if already found
  * Lookup symbols in libc in constructor
  * Fix: bad ret value check for default logging
  * Add compatibility with GNU/kFreeBSD
  * Fix compatibility with s390 and s390x architectures
  * Fix: missing registry unlock on error
  * Fix: undefined syscall values for x86
  * Fix: check fileno returned value
  * Fix: torsocks.in libdir path with lib prefix
  * Tests: add config-file tests
  * Tests: add utils unit tests
  2013-09-02 torsocks 2.0.0-rc2
  * Fix: remove FAQ file from Makefile
  * Fix: remove out of date and inaccurate FAQ
  * Tests: add connection object unit test
  * Fix: Improve README file
  * Tests: add onion pool subsystem unit test
  * Use extern for tsocks_libc_* in torsocks.h
  * Define LIBC_SYSCALL_ for OS X
  * Make sure __darwin__ is defined
  * Fix: explicitly ignore fileno return value
  * Use AC_CHECK_FUNC rather than AC_LINK_IFELSE.
  * Find out if we really need libdl.
  * Define LIBC_SYSCALL_ for FreeBSD.
  * Use SYS_ from <sys/syscall.h>.
  * Include <sys/socket.h> for AF_INET*.
  * Use getsockname(2) for finding out socket address family
  2013-08-24 torsocks 2.0.0-rc1
  * Major rewrite from version 1.4
  * Libc TCP communication support
  * Libc DNS calls support
  * syscall() support
  * Unix socket FD passing support
  * IPv6 ready
  * Thread safe
  Torsocks 1.4
  XXX
    o Added .travis.yml for travis-ci integration:
    https://travis-ci.org/ioerror/torsocks
- Change Source0 Web URL
- Remove obsolete patch torsocks-1.3-src_usewithtor.in.patch,
  changed by Upstream
- Use /etc/tor/torsocks.conf instead of /etc/torsocks.conf
- Use torsocks instead of usewithtor
- Change Documentation, use --docdir=%%{_defaultdocdir}/%%{name}
* Mon Dec 29 2014 nemysis@gmx.ch
- Use for patch %%{name}-1.3-src_usewithtor.in.patch
  instead of  %%{name}-%%{version}-src_usewithtor.in.patch
* Sat Dec  6 2014 nemysis@gmx.ch
- Fix typo
* Sat Dec  6 2014 nemysis@gmx.ch
- Use /etc/torsocks.conf instead of %%{_sysconfdir}/%%{name}.conf
* Sat Dec  6 2014 nemysis@gmx.ch
- Initial package creation
